#' schrute: The Entire Transcript from The Office in Tidy Format.
#'
#' Analyze and have fun with the text from the best series of all time
#'
#' @docType package
#' @name schrute
"_PACKAGE"
